@@ -64,16 +64,18 @@ def get_debug_msg(*args):
 
 
 def font_formatter(n, s):
-    # https://stackoverflow.com/questions/287871/how-to-print-colored-text-in-python/50025330
-
     code = {
-        "green": 92,
-        "red": 91,
-        "italic": 3,
-        "white": 37,
-        "blue": 34
+        "green": 46,
+        "red": 9,
+        "white": 252,
+        "debug": 138,  # 177
+        "blue": 75,
+        "orange": 208
     }
-    value = "\033[" + str(code[n]) + "m" + s + "\033[0m"
+    if n in ["italic"]:
+        value = "\033[3m{}\033[0m".format(s)
+    else:
+        value = "\033[38;5;{}m{}\033[0m".format((code[n]), s)
     return value
 
 
